#
# spec file for package vncmanager
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define vncgroup vnc
%define vncuser vnc

Name:           vncmanager
Version:        1.0.2
Release:        12.4
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libgnutls-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(zlib)
Requires(post): xorg-x11-Xvnc
Requires:       vncmanager-greeter
Requires:       xorg-x11-Xvnc
Requires:       xorg-x11-Xvnc:/usr/lib/vnc/with-vnc-key.sh
Recommends:     vncmanager-controller

URL:            https://github.com/openSUSE/vncmanager
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Session manager for VNC
License:        MIT
Group:          System/X11/Utilities
Source:         vncmanager-%{version}.tar.gz
Source1:        tmpfile.conf
Patch1:         n_use_port_5901.patch
Patch2:         n_use_with_vnc_key_wrapper.patch
Patch3:         U_Add-xvnc-args-configuration-option.patch
Patch4:         n_disable_mit_shm.patch
Patch5:         U_ControllerConnection-Split-iostream-into-istream-and.patch
Patch6:         n_vncmanager-add-target-to-service.patch
Patch7:         u_Fix_tight_decoder_on_888_encodings.patch
Patch8:         u_Fix-PixelFormat-ntoh-and-PixelFormat-hton.patch
Patch9:         u_Fix-TightCompressionControl-definition-for-big-endian.patch
Patch10:        n_UsrEtc.patch
Patch11:        u_Fix-Tight-Encoding-not-processing-pixel-format-prope.patch
Patch12:        u_Fix-missing-include.patch

%description
Session manager for VNC. It listens on VNC port and spawns Xvnc processes for incoming clients.

%pre
%service_add_pre vncmanager.service

%post
%service_add_post vncmanager.service
[ -x /usr/bin/systemd-tmpfiles ] && /usr/bin/systemd-tmpfiles --create %_tmpfilesdir/%{name}.conf || :

%preun
%service_del_preun vncmanager.service

%postun
%service_del_postun vncmanager.service

%prep
%autosetup -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_VERBOSE_MAKEFILE=ON
make %{?_smp_mflags}

%install
%cmake_install
mkdir -p %{buildroot}/etc/vnc

# tmpfiles
install -d -m 0755 %{buildroot}/usr/lib/tmpfiles.d/
install -m 0644 %{SOURCE1} %{buildroot}/usr/lib/tmpfiles.d/%{name}.conf

# systemd
mkdir -p %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcvncmanager

%files
%defattr(-,root,root)
%license LICENSE
%doc vncmanager.conf README.md
%{_bindir}/vncmanager
%{_unitdir}/vncmanager.service
%{_sbindir}/rcvncmanager
%dir %attr(0755,%{vncuser},%{vncuser}) %{_sysconfdir}/vnc
/usr/lib/tmpfiles.d/%{name}.conf
%ghost %dir /run/vncmanager

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Apr  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- u_Fix-missing-include.patch
  * Fix missing #include <cstdint> exposed by gcc 13.
- Rebase n_disable_mit_shm.patch with quilt.
* Wed Feb  9 2022 Joan Torres <joan.torres@suse.com>
-  u_Fix-Tight-Encoding-not-processing-pixel-format-prope.patch
  * Consider different pixel format depths on Tight Encoding.
    TightPixel was considering only pixels defined with 3 bytes.
    (bsc#1189247)
* Mon Jan  4 2021 Stefan Dirsch <sndirsch@suse.com>
- added pkgconfig BuildRequires for zlib and bzip2 in order to fix
  build against Tumbleweed/factory
* Wed Sep  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update n_use_with_vnc_key_wrapper.patch: use libexecdir as the
  path to with-vnc-key.sh (boo#1176064).
* Thu Jul  9 2020 Stefan Dirsch <sndirsch@suse.com>
- n_use_port_5901.patch
  * changed port number also in code, which sets the default, not
    only in config file (boo#1173047)
* Mon Jul  6 2020 Stefan Dirsch <sndirsch@suse.com>
- added n_UsrEtc.patch (boo#1173047)
  * no longer install vncmanager.conf sample as config file
  * added description of how to make use of vncmanager.conf sample
    to README.md
- added README.md as %%doc (boo#1173047)
* Thu May 21 2020 Petr Tesařík <ptesarik@suse.com>
- Adjust upstream project URL.
* Thu May 14 2020 Petr Tesařík <ptesarik@suse.com>
- u_Fix-TightCompressionControl-definition-for-big-endian.patch
  * Fix tight compression decoder on big-endian systems
    (bsc#1171344).
* Wed May 13 2020 Petr Tesařík <ptesarik@suse.com>
- u_Fix_tight_decoder_on_888_encodings.patch
  * Fix tight decoder with 888 pixel encodings. (bsc#1169732)
- u_Fix-PixelFormat-ntoh-and-PixelFormat-hton.patch
  * Fix PixelFormat::ntoh() and PixelFormat::hton(). (bsc#1169732)
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Mon Aug  6 2018 msrb@suse.com
- n_vncmanager-add-target-to-service.patch
  * Declare the service as part of xvnc.target so it can be used as
    dependency for xvnc-novnc.service. (bnc#1103552)
* Thu Feb 15 2018 msrb@suse.com
- U_ControllerConnection-Split-iostream-into-istream-and.patch
  * Do not try to seek on unix socket. (bnc#1076730)
* Fri Aug 11 2017 msrb@suse.com
- U_Add-xvnc-args-configuration-option.patch,
  n_disable_mit_shm.patch
  * Disable MIT-SHM extension in Xvnc started by vncmanager.
    (bnc#1053373)
* Mon May 22 2017 msrb@suse.com
- Update to 1.0.2
  * Fix crash when client disconnects during of TLS negotiation
  * Add geometry parameter (bnc#1038851)
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Jun 16 2016 msrb@suse.com
- Update to 1.0.1
  * Fix build with gcc 6, fix licence link in README. (bnc#985002)
- Add dependency on xorg-x11-Xvnc. (bnc#984461)
- Add n_use_with_vnc_key_wrapper.patch
  * Use with-vnc-key.sh wrapper to generate VNC key and certificate
    on first use. (bnc#982349)
* Thu May 12 2016 msrb@suse.com
- Add LICENSE file to docs.
- Expand %%tmpfiles_create macro.
* Thu May  5 2016 jengelh@inai.de
- %%make_jobs is not defined in SLE; but we can use make %%_smp_mflags
- systemd is not a hard runtime requirement (the macros support
  softfail)
* Fri Apr 29 2016 msrb@suse.com
- Change group to System/X11/Utilities.
* Wed Apr 27 2016 msrb@suse.com
- Update to v1.0.0.
* Wed Apr 27 2016 msrb@suse.com
- n_use_port_5901.patch
  * Use port 5901 to match tigervnc's xinetd based service.
* Mon Nov  9 2015 msrb@suse.com
- Create package.
